Documentation
¶
Overview ¶
The CDK Construct Library for Amazon EventBridge Pipes Enrichments
Index ¶
- func NewApiDestinationEnrichment_Override(a ApiDestinationEnrichment, destination awsevents.IApiDestination, ...)
- func NewApiGatewayEnrichment_Override(a ApiGatewayEnrichment, restApi awsapigateway.IRestApi, ...)
- func NewLambdaEnrichment_Override(l LambdaEnrichment, lambda awslambda.IFunction, props *LambdaEnrichmentProps)
- func NewStepFunctionsEnrichment_Override(s StepFunctionsEnrichment, stateMachine awsstepfunctions.IStateMachine, ...)
- type ApiDestinationEnrichment
- type ApiDestinationEnrichmentProps
- type ApiGatewayEnrichment
- type ApiGatewayEnrichmentProps
- type LambdaEnrichment
- type LambdaEnrichmentProps
- type StepFunctionsEnrichment
- type StepFunctionsEnrichmentProps
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewApiDestinationEnrichment_Override ¶
func NewApiDestinationEnrichment_Override(a ApiDestinationEnrichment, destination awsevents.IApiDestination, props *ApiDestinationEnrichmentProps)
Experimental.
func NewApiGatewayEnrichment_Override ¶
func NewApiGatewayEnrichment_Override(a ApiGatewayEnrichment, restApi awsapigateway.IRestApi, props *ApiGatewayEnrichmentProps)
Experimental.
func NewLambdaEnrichment_Override ¶
func NewLambdaEnrichment_Override(l LambdaEnrichment, lambda awslambda.IFunction, props *LambdaEnrichmentProps)
Experimental.
func NewStepFunctionsEnrichment_Override ¶
func NewStepFunctionsEnrichment_Override(s StepFunctionsEnrichment, stateMachine awsstepfunctions.IStateMachine, props *StepFunctionsEnrichmentProps)
Experimental.
Types ¶
type ApiDestinationEnrichment ¶
type ApiDestinationEnrichment interface {
awscdkpipesalpha.IEnrichment
// The ARN of the enrichment resource.
//
// Length Constraints: Minimum length of 0. Maximum length of 1600.
// Experimental.
EnrichmentArn() *string
// Bind this enrichment to a pipe.
// Experimental.
Bind(pipe awscdkpipesalpha.IPipe) *awscdkpipesalpha.EnrichmentParametersConfig
// Grant the pipes role to invoke the enrichment.
// Experimental.
GrantInvoke(grantee awsiam.IRole)
}
An API Destination enrichment for a pipe.
Example:
var sourceQueue Queue
var targetQueue Queue
var apiDestination ApiDestination
enrichment := enrichments.NewApiDestinationEnrichment(apiDestination)
pipe := pipes.NewPipe(this, jsii.String("Pipe"), &PipeProps{
Source: NewSomeSource(sourceQueue),
Enrichment: Enrichment,
Target: NewSomeTarget(targetQueue),
})
Experimental.
func NewApiDestinationEnrichment ¶
func NewApiDestinationEnrichment(destination awsevents.IApiDestination, props *ApiDestinationEnrichmentProps) ApiDestinationEnrichment
Experimental.
type ApiDestinationEnrichmentProps ¶
type ApiDestinationEnrichmentProps struct {
// The headers that need to be sent as part of request invoking the EventBridge ApiDestination.
// Default: - none.
//
// Experimental.
HeaderParameters *map[string]*string `field:"optional" json:"headerParameters" yaml:"headerParameters"`
// The input transformation for the enrichment.
// See: https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-input-transformation.html
//
// Default: - None.
//
// Experimental.
InputTransformation awscdkpipesalpha.InputTransformation `field:"optional" json:"inputTransformation" yaml:"inputTransformation"`
// The path parameter values used to populate the EventBridge API destination path wildcards ("*").
// Default: - none.
//
// Experimental.
PathParameterValues *[]*string `field:"optional" json:"pathParameterValues" yaml:"pathParameterValues"`
// The query string keys/values that need to be sent as part of request invoking the EventBridge API destination.
// Default: - none.
//
// Experimental.
QueryStringParameters *map[string]*string `field:"optional" json:"queryStringParameters" yaml:"queryStringParameters"`
}
Properties for a ApiDestinationEnrichment.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import pipes_alpha "github.com/aws/aws-cdk-go/awscdkpipesalpha"
import pipes_enrichments_alpha "github.com/aws/aws-cdk-go/awscdkpipesenrichmentsalpha"
var inputTransformation InputTransformation
apiDestinationEnrichmentProps := &ApiDestinationEnrichmentProps{
HeaderParameters: map[string]*string{
"headerParametersKey": jsii.String("headerParameters"),
},
InputTransformation: inputTransformation,
PathParameterValues: []*string{
jsii.String("pathParameterValues"),
},
QueryStringParameters: map[string]*string{
"queryStringParametersKey": jsii.String("queryStringParameters"),
},
}
Experimental.
type ApiGatewayEnrichment ¶
type ApiGatewayEnrichment interface {
awscdkpipesalpha.IEnrichment
// The ARN of the enrichment resource.
//
// Length Constraints: Minimum length of 0. Maximum length of 1600.
// Experimental.
EnrichmentArn() *string
// Bind this enrichment to a pipe.
// Experimental.
Bind(pipe awscdkpipesalpha.IPipe) *awscdkpipesalpha.EnrichmentParametersConfig
// Grant the pipes role to invoke the enrichment.
// Experimental.
GrantInvoke(grantee awsiam.IRole)
}
An API Gateway enrichment for a pipe.
Example:
var sourceQueue Queue
var targetQueue Queue
var restApi RestApi
enrichment := enrichments.NewApiGatewayEnrichment(restApi)
pipe := pipes.NewPipe(this, jsii.String("Pipe"), &PipeProps{
Source: NewSomeSource(sourceQueue),
Enrichment: Enrichment,
Target: NewSomeTarget(targetQueue),
})
Experimental.
func NewApiGatewayEnrichment ¶
func NewApiGatewayEnrichment(restApi awsapigateway.IRestApi, props *ApiGatewayEnrichmentProps) ApiGatewayEnrichment
Experimental.
type ApiGatewayEnrichmentProps ¶
type ApiGatewayEnrichmentProps struct {
// The headers that need to be sent as part of request invoking the API Gateway REST API.
// Default: - none.
//
// Experimental.
HeaderParameters *map[string]*string `field:"optional" json:"headerParameters" yaml:"headerParameters"`
// The input transformation for the enrichment.
// See: https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-input-transformation.html
//
// Default: - None.
//
// Experimental.
InputTransformation awscdkpipesalpha.InputTransformation `field:"optional" json:"inputTransformation" yaml:"inputTransformation"`
// The method for API Gateway resource.
// Default: '*' - ANY.
//
// Experimental.
Method *string `field:"optional" json:"method" yaml:"method"`
// The path for the API Gateway resource.
// Default: '/'.
//
// Experimental.
Path *string `field:"optional" json:"path" yaml:"path"`
// The path parameter values used to populate the API Gateway REST API path wildcards ("*").
// Default: - none.
//
// Experimental.
PathParameterValues *[]*string `field:"optional" json:"pathParameterValues" yaml:"pathParameterValues"`
// The query string keys/values that need to be sent as part of request invoking the EventBridge API destination.
// Default: - none.
//
// Experimental.
QueryStringParameters *map[string]*string `field:"optional" json:"queryStringParameters" yaml:"queryStringParameters"`
// The deployment stage for the API Gateway resource.
// Default: - the value of `deploymentStage.stageName` of target API Gateway resource.
//
// Experimental.
Stage *string `field:"optional" json:"stage" yaml:"stage"`
}
Properties for a ApiGatewayEnrichment.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import pipes_alpha "github.com/aws/aws-cdk-go/awscdkpipesalpha"
import pipes_enrichments_alpha "github.com/aws/aws-cdk-go/awscdkpipesenrichmentsalpha"
var inputTransformation InputTransformation
apiGatewayEnrichmentProps := &ApiGatewayEnrichmentProps{
HeaderParameters: map[string]*string{
"headerParametersKey": jsii.String("headerParameters"),
},
InputTransformation: inputTransformation,
Method: jsii.String("method"),
Path: jsii.String("path"),
PathParameterValues: []*string{
jsii.String("pathParameterValues"),
},
QueryStringParameters: map[string]*string{
"queryStringParametersKey": jsii.String("queryStringParameters"),
},
Stage: jsii.String("stage"),
}
Experimental.
type LambdaEnrichment ¶
type LambdaEnrichment interface {
awscdkpipesalpha.IEnrichment
// The ARN of the enrichment resource.
//
// Length Constraints: Minimum length of 0. Maximum length of 1600.
// Experimental.
EnrichmentArn() *string
// Bind this enrichment to a pipe.
// Experimental.
Bind(pipe awscdkpipesalpha.IPipe) *awscdkpipesalpha.EnrichmentParametersConfig
// Grant the pipes role to invoke the enrichment.
// Experimental.
GrantInvoke(grantee awsiam.IRole)
}
A Lambda enrichment for a pipe.
Example:
var sourceQueue Queue
var targetQueue Queue
var enrichmentFunction Function
enrichment := enrichments.NewLambdaEnrichment(enrichmentFunction)
pipe := pipes.NewPipe(this, jsii.String("Pipe"), &PipeProps{
Source: NewSomeSource(sourceQueue),
Enrichment: Enrichment,
Target: NewSomeTarget(targetQueue),
})
Experimental.
func NewLambdaEnrichment ¶
func NewLambdaEnrichment(lambda awslambda.IFunction, props *LambdaEnrichmentProps) LambdaEnrichment
Experimental.
type LambdaEnrichmentProps ¶
type LambdaEnrichmentProps struct {
// The input transformation for the enrichment.
// See: https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-input-transformation.html
//
// Default: - None.
//
// Experimental.
InputTransformation awscdkpipesalpha.InputTransformation `field:"optional" json:"inputTransformation" yaml:"inputTransformation"`
}
Properties for a LambdaEnrichment.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import pipes_alpha "github.com/aws/aws-cdk-go/awscdkpipesalpha"
import pipes_enrichments_alpha "github.com/aws/aws-cdk-go/awscdkpipesenrichmentsalpha"
var inputTransformation InputTransformation
lambdaEnrichmentProps := &LambdaEnrichmentProps{
InputTransformation: inputTransformation,
}
Experimental.
type StepFunctionsEnrichment ¶
type StepFunctionsEnrichment interface {
awscdkpipesalpha.IEnrichment
// The ARN of the enrichment resource.
//
// Length Constraints: Minimum length of 0. Maximum length of 1600.
// Experimental.
EnrichmentArn() *string
// Bind this enrichment to a pipe.
// Experimental.
Bind(pipe awscdkpipesalpha.IPipe) *awscdkpipesalpha.EnrichmentParametersConfig
// Grant the pipes role to invoke the enrichment.
// Experimental.
GrantInvoke(grantee awsiam.IRole)
}
A StepFunctions enrichment for a pipe.
Example:
var sourceQueue Queue
var targetQueue Queue
var enrichmentStateMachine StateMachine
enrichment := enrichments.NewStepFunctionsEnrichment(enrichmentStateMachine)
pipe := pipes.NewPipe(this, jsii.String("Pipe"), &PipeProps{
Source: NewSomeSource(sourceQueue),
Enrichment: Enrichment,
Target: NewSomeTarget(targetQueue),
})
Experimental.
func NewStepFunctionsEnrichment ¶
func NewStepFunctionsEnrichment(stateMachine awsstepfunctions.IStateMachine, props *StepFunctionsEnrichmentProps) StepFunctionsEnrichment
Experimental.
type StepFunctionsEnrichmentProps ¶
type StepFunctionsEnrichmentProps struct {
// The input transformation for the enrichment.
// See: https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-input-transformation.html
//
// Default: - None.
//
// Experimental.
InputTransformation awscdkpipesalpha.InputTransformation `field:"optional" json:"inputTransformation" yaml:"inputTransformation"`
}
Properties for a StepFunctionsEnrichment.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import pipes_alpha "github.com/aws/aws-cdk-go/awscdkpipesalpha"
import pipes_enrichments_alpha "github.com/aws/aws-cdk-go/awscdkpipesenrichmentsalpha"
var inputTransformation InputTransformation
stepFunctionsEnrichmentProps := &StepFunctionsEnrichmentProps{
InputTransformation: inputTransformation,
}
Experimental.
Source Files
¶
- ApiDestinationEnrichment.go
- ApiDestinationEnrichmentProps.go
- ApiDestinationEnrichment__checks.go
- ApiGatewayEnrichment.go
- ApiGatewayEnrichmentProps.go
- ApiGatewayEnrichment__checks.go
- LambdaEnrichment.go
- LambdaEnrichmentProps.go
- LambdaEnrichment__checks.go
- StepFunctionsEnrichment.go
- StepFunctionsEnrichmentProps.go
- StepFunctionsEnrichment__checks.go
- main.go