Documentation
¶
Index ¶
- func CfnDataTransformationProfile_ArnForDataTransformationProfile(resource interfacesawshealthlake.IDataTransformationProfileRef) *string
- func CfnDataTransformationProfile_CFN_RESOURCE_TYPE_NAME() *string
- func CfnDataTransformationProfile_IsCfnDataTransformationProfile(x interface{}) *bool
- func CfnDataTransformationProfile_IsCfnElement(x interface{}) *bool
- func CfnDataTransformationProfile_IsCfnResource(x interface{}) *bool
- func CfnDataTransformationProfile_IsConstruct(x interface{}) *bool
- func CfnFHIRDatastore_ArnForFHIRDatastore(resource interfacesawshealthlake.IFHIRDatastoreRef) *string
- func CfnFHIRDatastore_CFN_RESOURCE_TYPE_NAME() *string
- func CfnFHIRDatastore_FromDatastoreId(scope constructs.Construct, id *string, datastoreId *string) interfacesawshealthlake.IFHIRDatastoreRef
- func CfnFHIRDatastore_FromFHIRDatastoreArn(scope constructs.Construct, id *string, arn *string) interfacesawshealthlake.IFHIRDatastoreRef
- func CfnFHIRDatastore_IsCfnElement(x interface{}) *bool
- func CfnFHIRDatastore_IsCfnFHIRDatastore(x interface{}) *bool
- func CfnFHIRDatastore_IsCfnResource(x interface{}) *bool
- func CfnFHIRDatastore_IsConstruct(x interface{}) *bool
- func NewCfnDataTransformationProfile_Override(c CfnDataTransformationProfile, scope constructs.Construct, id *string, ...)
- func NewCfnFHIRDatastore_Override(c CfnFHIRDatastore, scope constructs.Construct, id *string, ...)
- type CfnDataTransformationProfile
- type CfnDataTransformationProfileProps
- type CfnDataTransformationProfile_ExistingVersionedProfileSourceProperty
- type CfnDataTransformationProfile_ProfileMappingSourceProperty
- type CfnDataTransformationProfile_SourceProperty
- type CfnDataTransformationProfile_StarterProfileSourceProperty
- type CfnFHIRDatastore
- type CfnFHIRDatastoreProps
- type CfnFHIRDatastore_CreatedAtProperty
- type CfnFHIRDatastore_IdentityProviderConfigurationProperty
- type CfnFHIRDatastore_KmsEncryptionConfigProperty
- type CfnFHIRDatastore_PreloadDataConfigProperty
- type CfnFHIRDatastore_SseConfigurationProperty
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CfnDataTransformationProfile_ArnForDataTransformationProfile ¶ added in v2.264.0
func CfnDataTransformationProfile_ArnForDataTransformationProfile(resource interfacesawshealthlake.IDataTransformationProfileRef) *string
func CfnDataTransformationProfile_CFN_RESOURCE_TYPE_NAME ¶ added in v2.264.0
func CfnDataTransformationProfile_CFN_RESOURCE_TYPE_NAME() *string
func CfnDataTransformationProfile_IsCfnDataTransformationProfile ¶ added in v2.264.0
func CfnDataTransformationProfile_IsCfnDataTransformationProfile(x interface{}) *bool
Checks whether the given object is a CfnDataTransformationProfile.
func CfnDataTransformationProfile_IsCfnElement ¶ added in v2.264.0
func CfnDataTransformationProfile_IsCfnElement(x interface{}) *bool
Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).
Uses duck-typing instead of `instanceof` to allow stack elements from different versions of this library to be included in the same stack.
Returns: The construct as a stack element or undefined if it is not a stack element.
func CfnDataTransformationProfile_IsCfnResource ¶ added in v2.264.0
func CfnDataTransformationProfile_IsCfnResource(x interface{}) *bool
Check whether the given object is a CfnResource.
func CfnDataTransformationProfile_IsConstruct ¶ added in v2.264.0
func CfnDataTransformationProfile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CfnFHIRDatastore_ArnForFHIRDatastore ¶ added in v2.227.0
func CfnFHIRDatastore_ArnForFHIRDatastore(resource interfacesawshealthlake.IFHIRDatastoreRef) *string
func CfnFHIRDatastore_CFN_RESOURCE_TYPE_NAME ¶
func CfnFHIRDatastore_CFN_RESOURCE_TYPE_NAME() *string
func CfnFHIRDatastore_FromDatastoreId ¶ added in v2.218.0
func CfnFHIRDatastore_FromDatastoreId(scope constructs.Construct, id *string, datastoreId *string) interfacesawshealthlake.IFHIRDatastoreRef
Creates a new IFHIRDatastoreRef from a datastoreId.
func CfnFHIRDatastore_FromFHIRDatastoreArn ¶ added in v2.231.0
func CfnFHIRDatastore_FromFHIRDatastoreArn(scope constructs.Construct, id *string, arn *string) interfacesawshealthlake.IFHIRDatastoreRef
Creates a new IFHIRDatastoreRef from an ARN.
func CfnFHIRDatastore_IsCfnElement ¶
func CfnFHIRDatastore_IsCfnElement(x interface{}) *bool
Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).
Uses duck-typing instead of `instanceof` to allow stack elements from different versions of this library to be included in the same stack.
Returns: The construct as a stack element or undefined if it is not a stack element.
func CfnFHIRDatastore_IsCfnFHIRDatastore ¶ added in v2.231.0
func CfnFHIRDatastore_IsCfnFHIRDatastore(x interface{}) *bool
Checks whether the given object is a CfnFHIRDatastore.
func CfnFHIRDatastore_IsCfnResource ¶
func CfnFHIRDatastore_IsCfnResource(x interface{}) *bool
Check whether the given object is a CfnResource.
func CfnFHIRDatastore_IsConstruct ¶
func CfnFHIRDatastore_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NewCfnDataTransformationProfile_Override ¶ added in v2.264.0
func NewCfnDataTransformationProfile_Override(c CfnDataTransformationProfile, scope constructs.Construct, id *string, props *CfnDataTransformationProfileProps)
Create a new `AWS::HealthLake::DataTransformationProfile`.
func NewCfnFHIRDatastore_Override ¶
func NewCfnFHIRDatastore_Override(c CfnFHIRDatastore, scope constructs.Construct, id *string, props *CfnFHIRDatastoreProps)
Create a new `AWS::HealthLake::FHIRDatastore`.
Types ¶
type CfnDataTransformationProfile ¶ added in v2.264.0
type CfnDataTransformationProfile interface {
awscdk.CfnResource
awscdk.IInspectable
interfacesawshealthlake.IDataTransformationProfileRef
awscdk.ITaggableV2
// The Amazon Resource Name (ARN) of the data transformation profile.
AttrArn() *string
// The unique, server-generated identifier of the profile (32-character lowercase hexadecimal).
AttrProfileId() *string
// The target format that this profile converts to.
//
// Always FHIR_R4.
AttrTargetFormat() *string
// Tag Manager which manages the tags for this resource.
CdkTagManager() awscdk.TagManager
// Options for this resource, such as condition, update policy etc.
CfnOptions() awscdk.ICfnResourceOptions
CfnProperties() *map[string]interface{}
CfnPropertyNames() *map[string]*string
// AWS resource type.
CfnResourceType() *string
// Returns: the stack trace of the point where this Resource was created from, sourced
// from the +metadata+ entry typed +aws:cdk:logicalId+, and with the bottom-most
// node +internal+ entries filtered.
CreationStack() *[]*string
// A reference to a DataTransformationProfile resource.
DataTransformationProfileRef() *interfacesawshealthlake.DataTransformationProfileReference
Env() *interfaces.ResourceEnvironment
// The identifier (key ID or ARN) of a customer-managed KMS key used to encrypt the profile's template content at rest.
KmsKeyId() *string
SetKmsKeyId(val *string)
// The logical ID for this CloudFormation stack element.
//
// The logical ID of the element
// is calculated from the path of the resource node in the construct tree.
//
// To override this value, use `overrideLogicalId(newLogicalId)`.
//
// Returns: the logical ID as a stringified token. This value will only get
// resolved during synthesis.
LogicalId() *string
// The tree node.
Node() constructs.Node
// A human-readable description of the profile's purpose.
ProfileDescription() *string
SetProfileDescription(val *string)
// The human-readable name of the profile.
ProfileName() *string
SetProfileName(val *string)
// Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.
//
// If, by any chance, the intrinsic reference of a resource is not a string, you could
// coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.
Ref() *string
// The source from which to create the profile's initial template content.
Source() interface{}
SetSource(val interface{})
// The source format that this profile converts from.
SourceFormat() *string
SetSourceFormat(val *string)
// The stack in which this element is defined.
//
// CfnElements must be defined within a stack scope (directly or indirectly).
Stack() awscdk.Stack
// An array of key-value pairs to apply to this profile.
Tags() *[]*awscdk.CfnTag
SetTags(val *[]*awscdk.CfnTag)
// Deprecated.
// Deprecated: use `updatedProperties`
//
// Return properties modified after initiation
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperites() *map[string]interface{}
// Return properties modified after initiation.
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperties() *map[string]interface{}
// Syntactic sugar for `addOverride(path, undefined)`.
AddDeletionOverride(path *string)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This method has been renamed to `addResourceDependency` to more clearly
// set it apart from `construct.node.addDependency`. See the documentation
// of that function for more details.
// Deprecated: Use `addResourceDependency` instead.
AddDependency(target awscdk.CfnResource)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
//
// This method has been renamed to `addResourceDependency`, which makes it
// more clear that this method operates at a different level from the
// construct-level `construct.node.addDependency()` mechanism.
// Deprecated: Use `addResourceDependency` instead.
AddDependsOn(target awscdk.CfnResource)
// Add a value to the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
AddMetadata(key *string, value interface{})
// Adds an override to the synthesized CloudFormation resource.
//
// To add a
// property override, either use `addPropertyOverride` or prefix `path` with
// "Properties." (i.e. `Properties.TopicName`).
//
// If the override is nested, separate each nested level using a dot (.) in the path parameter.
// If there is an array as part of the nesting, specify the index in the path.
//
// To include a literal `.` in the property name, prefix with a `\`. In most
// programming languages you will need to write this as `"\\."` because the
// `\` itself will need to be escaped.
//
// For example,
// “`typescript
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
// “`
// would add the overrides
// “`json
// "Properties": {
// "GlobalSecondaryIndexes": [
// {
// "Projection": {
// "NonKeyAttributes": [ "myattribute" ]
// ...
// }
// ...
// },
// {
// "ProjectionType": "INCLUDE"
// ...
// },
// ]
// ...
// }
// “`
//
// The `value` argument to `addOverride` will not be processed or translated
// in any way. Pass raw JSON values in here with the correct capitalization
// for CloudFormation. If you pass CDK classes or structs, they will be
// rendered with lowercased key names, and CloudFormation will reject the
// template.
AddOverride(path *string, value interface{})
// Adds an override that deletes the value of a property from the resource definition.
AddPropertyDeletionOverride(propertyPath *string)
// Adds an override to a resource property.
//
// Syntactic sugar for `addOverride("Properties.<...>", value)`.
AddPropertyOverride(propertyPath *string, value interface{})
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
//
// This method only adds dependencies between L1 resources. If you are
// looking for a generic construct-to-construct dependency mechanism that works
// for all constructs including L2s, use `construct.node.addDependency` instead.
AddResourceDependency(target awscdk.CfnResource, reason *string)
// Sets the cross-stack reference strength for this resource.
//
// When set, any cross-stack reference to this resource will use the specified
// strength instead of the global default from the consuming stack's context.
ApplyCrossStackReferenceStrength(strength awscdk.ReferenceStrength)
// Sets the deletion policy of the resource based on the removal policy specified.
//
// The Removal Policy controls what happens to this resource when it stops
// being managed by CloudFormation, either because you've removed it from the
// CDK application or because you've made a change that requires the resource
// to be replaced.
//
// The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
// account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
// cases, a snapshot can be taken of the resource prior to deletion
// (`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
// can be found in the following link:.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
//
ApplyRemovalPolicy(policy awscdk.RemovalPolicy, options *awscdk.RemovalPolicyOptions)
CfnPropertyName(cdkPropertyName *string) *string
// Returns a token for an runtime attribute of this resource.
//
// Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
// in case there is no generated attribute.
GetAtt(attributeName *string, typeHint awscdk.ResolutionTypeHint) awscdk.Reference
// Retrieve a value value from the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
GetMetadata(key *string) interface{}
// Examines the CloudFormation resource and discloses attributes.
Inspect(inspector awscdk.TreeInspector)
// Retrieves an array of resources and stacks this resource depends on.
//
// For resources depended on directly, returns the `CfnResource` object. For
// dependencies on other stacks, returns the `Stack` object. The order of the
// array is not guaranteed.
ObtainDependencies() *[]interface{}
// Overrides the auto-generated logical ID with a specific ID.
OverrideLogicalId(newLogicalId *string)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
// Deprecated: Use `removeResourceDependency` instead.
RemoveDependency(target awscdk.CfnResource)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
RemoveResourceDependency(target awscdk.CfnResource)
RenderProperties(props *map[string]interface{}) *map[string]interface{}
// Replaces one dependency with another.
ReplaceDependency(target awscdk.CfnResource, newTarget awscdk.CfnResource)
// Can be overridden by subclasses to determine if this resource will be rendered into the cloudformation template.
//
// Returns: `true` if the resource should be included or `false` is the resource
// should be omitted.
ShouldSynthesize() *bool
// Returns a string representation of this construct.
//
// Returns: a string representation of this resource.
ToString() *string
ValidateProperties(_properties interface{})
// Applies one or more mixins to this construct.
//
// Mixins are applied in order. The list of constructs is captured at the
// start of the call, so constructs added by a mixin will not be visited.
// Use multiple `with()` calls if subsequent mixins should apply to added
// constructs.
With(mixins ...constructs.IMixin) constructs.IConstruct
}
Creates a Data Transformation Profile in AWS HealthLake that converts healthcare data from a source format (such as C-CDA or CSV) into FHIR R4.
A profile is immutable once created; to change its template content, replace the resource. Only its tags can be updated in place.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnDataTransformationProfile := awscdk.Aws_healthlake.NewCfnDataTransformationProfile(this, jsii.String("MyCfnDataTransformationProfile"), &CfnDataTransformationProfileProps{
ProfileName: jsii.String("profileName"),
SourceFormat: jsii.String("sourceFormat"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
ProfileDescription: jsii.String("profileDescription"),
Source: &SourceProperty{
ExistingVersionedProfileId: &ExistingVersionedProfileSourceProperty{
ProfileId: jsii.String("profileId"),
Version: jsii.Number(123),
},
ProfileMapping: &ProfileMappingSourceProperty{
ProfileMapping: map[string]*string{
"profileMappingKey": jsii.String("profileMapping"),
},
},
StarterProfile: &StarterProfileSourceProperty{
StarterProfileName: jsii.String("starterProfileName"),
},
},
Tags: []CfnTag{
&CfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
})
func NewCfnDataTransformationProfile ¶ added in v2.264.0
func NewCfnDataTransformationProfile(scope constructs.Construct, id *string, props *CfnDataTransformationProfileProps) CfnDataTransformationProfile
Create a new `AWS::HealthLake::DataTransformationProfile`.
type CfnDataTransformationProfileProps ¶ added in v2.264.0
type CfnDataTransformationProfileProps struct {
// The human-readable name of the profile.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-profilename
//
ProfileName *string `field:"required" json:"profileName" yaml:"profileName"`
// The source format that this profile converts from.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-sourceformat
//
SourceFormat *string `field:"required" json:"sourceFormat" yaml:"sourceFormat"`
// The identifier (key ID or ARN) of a customer-managed KMS key used to encrypt the profile's template content at rest.
//
// If omitted, an AWS owned key is used.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-kmskeyid
//
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// A human-readable description of the profile's purpose.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-profiledescription
//
ProfileDescription *string `field:"optional" json:"profileDescription" yaml:"profileDescription"`
// The source from which to create the profile's initial template content.
//
// Exactly one of the members must be specified. Use StarterProfile (C-CDA only), ProfileMapping (C-CDA or CSV), or ExistingVersionedProfileId to clone an existing profile. Each produces a published profile.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-source
//
Source interface{} `field:"optional" json:"source" yaml:"source"`
// An array of key-value pairs to apply to this profile.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-datatransformationprofile.html#cfn-healthlake-datatransformationprofile-tags
//
Tags *[]*awscdk.CfnTag `field:"optional" json:"tags" yaml:"tags"`
}
Properties for defining a `CfnDataTransformationProfile`.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnDataTransformationProfileProps := &CfnDataTransformationProfileProps{
ProfileName: jsii.String("profileName"),
SourceFormat: jsii.String("sourceFormat"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
ProfileDescription: jsii.String("profileDescription"),
Source: &SourceProperty{
ExistingVersionedProfileId: &ExistingVersionedProfileSourceProperty{
ProfileId: jsii.String("profileId"),
Version: jsii.Number(123),
},
ProfileMapping: &ProfileMappingSourceProperty{
ProfileMapping: map[string]*string{
"profileMappingKey": jsii.String("profileMapping"),
},
},
StarterProfile: &StarterProfileSourceProperty{
StarterProfileName: jsii.String("starterProfileName"),
},
},
Tags: []CfnTag{
&CfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
}
type CfnDataTransformationProfile_ExistingVersionedProfileSourceProperty ¶ added in v2.264.0
type CfnDataTransformationProfile_ExistingVersionedProfileSourceProperty struct {
// The unique identifier of the source profile to clone.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-existingversionedprofilesource.html#cfn-healthlake-datatransformationprofile-existingversionedprofilesource-profileid
//
ProfileId *string `field:"required" json:"profileId" yaml:"profileId"`
// The version number of the source profile to clone.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-existingversionedprofilesource.html#cfn-healthlake-datatransformationprofile-existingversionedprofilesource-version
//
Version *float64 `field:"required" json:"version" yaml:"version"`
}
Create the profile by cloning a specific version of an existing profile.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
existingVersionedProfileSourceProperty := &ExistingVersionedProfileSourceProperty{
ProfileId: jsii.String("profileId"),
Version: jsii.Number(123),
}
type CfnDataTransformationProfile_ProfileMappingSourceProperty ¶ added in v2.264.0
type CfnDataTransformationProfile_ProfileMappingSourceProperty struct {
// Map of template file paths to their Velocity template content.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-profilemappingsource.html#cfn-healthlake-datatransformationprofile-profilemappingsource-profilemapping
//
ProfileMapping interface{} `field:"required" json:"profileMapping" yaml:"profileMapping"`
}
Create the profile from raw Velocity template mapping content.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
profileMappingSourceProperty := &ProfileMappingSourceProperty{
ProfileMapping: map[string]*string{
"profileMappingKey": jsii.String("profileMapping"),
},
}
type CfnDataTransformationProfile_SourceProperty ¶ added in v2.264.0
type CfnDataTransformationProfile_SourceProperty struct {
// Create the profile by cloning a specific version of an existing profile.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-source.html#cfn-healthlake-datatransformationprofile-source-existingversionedprofileid
//
ExistingVersionedProfileId interface{} `field:"optional" json:"existingVersionedProfileId" yaml:"existingVersionedProfileId"`
// Create the profile from raw Velocity template mapping content.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-source.html#cfn-healthlake-datatransformationprofile-source-profilemapping
//
ProfileMapping interface{} `field:"optional" json:"profileMapping" yaml:"profileMapping"`
// Create the profile from a predefined starter profile of transformation templates.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-source.html#cfn-healthlake-datatransformationprofile-source-starterprofile
//
StarterProfile interface{} `field:"optional" json:"starterProfile" yaml:"starterProfile"`
}
The source from which to create the profile's initial template content.
Exactly one of the members must be specified. Use StarterProfile (C-CDA only), ProfileMapping (C-CDA or CSV), or ExistingVersionedProfileId to clone an existing profile. Each produces a published profile.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
sourceProperty := &SourceProperty{
ExistingVersionedProfileId: &ExistingVersionedProfileSourceProperty{
ProfileId: jsii.String("profileId"),
Version: jsii.Number(123),
},
ProfileMapping: &ProfileMappingSourceProperty{
ProfileMapping: map[string]*string{
"profileMappingKey": jsii.String("profileMapping"),
},
},
StarterProfile: &StarterProfileSourceProperty{
StarterProfileName: jsii.String("starterProfileName"),
},
}
type CfnDataTransformationProfile_StarterProfileSourceProperty ¶ added in v2.264.0
type CfnDataTransformationProfile_StarterProfileSourceProperty struct {
// The name of the starter profile to seed the profile from.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-datatransformationprofile-starterprofilesource.html#cfn-healthlake-datatransformationprofile-starterprofilesource-starterprofilename
//
StarterProfileName *string `field:"required" json:"starterProfileName" yaml:"starterProfileName"`
}
Create the profile from a predefined starter profile of transformation templates.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
starterProfileSourceProperty := &StarterProfileSourceProperty{
StarterProfileName: jsii.String("starterProfileName"),
}
type CfnFHIRDatastore ¶
type CfnFHIRDatastore interface {
awscdk.CfnResource
awscdk.IInspectable
interfacesawshealthlake.IFHIRDatastoreRef
awscdk.ITaggable
// The time that a Data Store was created.
AttrCreatedAt() awscdk.IResolvable
AttrCreatedAtNanos() *float64
AttrCreatedAtSeconds() *string
// The Data Store ARN is generated during the creation of the Data Store and can be found in the output from the initial Data Store creation request.
AttrDatastoreArn() *string
// The endpoint for the created Data Store.
AttrDatastoreEndpoint() *string
// The Amazon generated Data Store id.
//
// This id is in the output from the initial Data Store creation call.
AttrDatastoreId() *string
// The status of the FHIR Data Store.
//
// Possible statuses are ‘CREATING’, ‘ACTIVE’, ‘DELETING’, ‘DELETED’.
AttrDatastoreStatus() *string
// Options for this resource, such as condition, update policy etc.
CfnOptions() awscdk.ICfnResourceOptions
CfnProperties() *map[string]interface{}
CfnPropertyNames() *map[string]*string
// AWS resource type.
CfnResourceType() *string
// Returns: the stack trace of the point where this Resource was created from, sourced
// from the +metadata+ entry typed +aws:cdk:logicalId+, and with the bottom-most
// node +internal+ entries filtered.
CreationStack() *[]*string
// The data store name (user-generated).
DatastoreName() *string
SetDatastoreName(val *string)
// The FHIR release version supported by the data store.
DatastoreTypeVersion() *string
SetDatastoreTypeVersion(val *string)
Env() *interfaces.ResourceEnvironment
// A reference to a FHIRDatastore resource.
FhirDatastoreRef() *interfacesawshealthlake.FHIRDatastoreReference
// The identity provider configuration selected when the data store was created.
IdentityProviderConfiguration() interface{}
SetIdentityProviderConfiguration(val interface{})
// The logical ID for this CloudFormation stack element.
//
// The logical ID of the element
// is calculated from the path of the resource node in the construct tree.
//
// To override this value, use `overrideLogicalId(newLogicalId)`.
//
// Returns: the logical ID as a stringified token. This value will only get
// resolved during synthesis.
LogicalId() *string
// The tree node.
Node() constructs.Node
// The preloaded Synthea data configuration for the data store.
PreloadDataConfig() interface{}
SetPreloadDataConfig(val interface{})
// Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.
//
// If, by any chance, the intrinsic reference of a resource is not a string, you could
// coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.
Ref() *string
// The server-side encryption key configuration for a customer-provided encryption key specified for creating a data store.
SseConfiguration() interface{}
SetSseConfiguration(val interface{})
// The stack in which this element is defined.
//
// CfnElements must be defined within a stack scope (directly or indirectly).
Stack() awscdk.Stack
// Tag Manager which manages the tags for this resource.
Tags() awscdk.TagManager
// An array of key-value pairs to apply to this resource.
TagsRaw() *[]*awscdk.CfnTag
SetTagsRaw(val *[]*awscdk.CfnTag)
// Deprecated.
// Deprecated: use `updatedProperties`
//
// Return properties modified after initiation
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperites() *map[string]interface{}
// Return properties modified after initiation.
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperties() *map[string]interface{}
// Syntactic sugar for `addOverride(path, undefined)`.
AddDeletionOverride(path *string)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This method has been renamed to `addResourceDependency` to more clearly
// set it apart from `construct.node.addDependency`. See the documentation
// of that function for more details.
// Deprecated: Use `addResourceDependency` instead.
AddDependency(target awscdk.CfnResource)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
//
// This method has been renamed to `addResourceDependency`, which makes it
// more clear that this method operates at a different level from the
// construct-level `construct.node.addDependency()` mechanism.
// Deprecated: Use `addResourceDependency` instead.
AddDependsOn(target awscdk.CfnResource)
// Add a value to the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
AddMetadata(key *string, value interface{})
// Adds an override to the synthesized CloudFormation resource.
//
// To add a
// property override, either use `addPropertyOverride` or prefix `path` with
// "Properties." (i.e. `Properties.TopicName`).
//
// If the override is nested, separate each nested level using a dot (.) in the path parameter.
// If there is an array as part of the nesting, specify the index in the path.
//
// To include a literal `.` in the property name, prefix with a `\`. In most
// programming languages you will need to write this as `"\\."` because the
// `\` itself will need to be escaped.
//
// For example,
// “`typescript
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
// “`
// would add the overrides
// “`json
// "Properties": {
// "GlobalSecondaryIndexes": [
// {
// "Projection": {
// "NonKeyAttributes": [ "myattribute" ]
// ...
// }
// ...
// },
// {
// "ProjectionType": "INCLUDE"
// ...
// },
// ]
// ...
// }
// “`
//
// The `value` argument to `addOverride` will not be processed or translated
// in any way. Pass raw JSON values in here with the correct capitalization
// for CloudFormation. If you pass CDK classes or structs, they will be
// rendered with lowercased key names, and CloudFormation will reject the
// template.
AddOverride(path *string, value interface{})
// Adds an override that deletes the value of a property from the resource definition.
AddPropertyDeletionOverride(propertyPath *string)
// Adds an override to a resource property.
//
// Syntactic sugar for `addOverride("Properties.<...>", value)`.
AddPropertyOverride(propertyPath *string, value interface{})
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
//
// This method only adds dependencies between L1 resources. If you are
// looking for a generic construct-to-construct dependency mechanism that works
// for all constructs including L2s, use `construct.node.addDependency` instead.
AddResourceDependency(target awscdk.CfnResource, reason *string)
// Sets the cross-stack reference strength for this resource.
//
// When set, any cross-stack reference to this resource will use the specified
// strength instead of the global default from the consuming stack's context.
ApplyCrossStackReferenceStrength(strength awscdk.ReferenceStrength)
// Sets the deletion policy of the resource based on the removal policy specified.
//
// The Removal Policy controls what happens to this resource when it stops
// being managed by CloudFormation, either because you've removed it from the
// CDK application or because you've made a change that requires the resource
// to be replaced.
//
// The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
// account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
// cases, a snapshot can be taken of the resource prior to deletion
// (`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
// can be found in the following link:.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
//
ApplyRemovalPolicy(policy awscdk.RemovalPolicy, options *awscdk.RemovalPolicyOptions)
CfnPropertyName(cdkPropertyName *string) *string
// Returns a token for an runtime attribute of this resource.
//
// Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
// in case there is no generated attribute.
GetAtt(attributeName *string, typeHint awscdk.ResolutionTypeHint) awscdk.Reference
// Retrieve a value value from the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
GetMetadata(key *string) interface{}
// Examines the CloudFormation resource and discloses attributes.
Inspect(inspector awscdk.TreeInspector)
// Retrieves an array of resources and stacks this resource depends on.
//
// For resources depended on directly, returns the `CfnResource` object. For
// dependencies on other stacks, returns the `Stack` object. The order of the
// array is not guaranteed.
ObtainDependencies() *[]interface{}
// Overrides the auto-generated logical ID with a specific ID.
OverrideLogicalId(newLogicalId *string)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
// Deprecated: Use `removeResourceDependency` instead.
RemoveDependency(target awscdk.CfnResource)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
RemoveResourceDependency(target awscdk.CfnResource)
RenderProperties(props *map[string]interface{}) *map[string]interface{}
// Replaces one dependency with another.
ReplaceDependency(target awscdk.CfnResource, newTarget awscdk.CfnResource)
// Can be overridden by subclasses to determine if this resource will be rendered into the cloudformation template.
//
// Returns: `true` if the resource should be included or `false` is the resource
// should be omitted.
ShouldSynthesize() *bool
// Returns a string representation of this construct.
//
// Returns: a string representation of this resource.
ToString() *string
ValidateProperties(_properties interface{})
// Applies one or more mixins to this construct.
//
// Mixins are applied in order. The list of constructs is captured at the
// start of the call, so constructs added by a mixin will not be visited.
// Use multiple `with()` calls if subsequent mixins should apply to added
// constructs.
With(mixins ...constructs.IMixin) constructs.IConstruct
}
Creates a Data Store that can ingest and export FHIR formatted data.
> Please note that when a user tries to do an Update operation via CloudFormation, changes to the Data Store name, Type Version, PreloadDataConfig, or SSEConfiguration will delete their existing Data Store for the stack and create a new one. This will lead to potential loss of data.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnFHIRDatastore := awscdk.Aws_healthlake.NewCfnFHIRDatastore(this, jsii.String("MyCfnFHIRDatastore"), &CfnFHIRDatastoreProps{
DatastoreTypeVersion: jsii.String("datastoreTypeVersion"),
// the properties below are optional
DatastoreName: jsii.String("datastoreName"),
IdentityProviderConfiguration: &IdentityProviderConfigurationProperty{
AuthorizationStrategy: jsii.String("authorizationStrategy"),
// the properties below are optional
FineGrainedAuthorizationEnabled: jsii.Boolean(false),
IdpLambdaArn: jsii.String("idpLambdaArn"),
Metadata: jsii.String("metadata"),
},
PreloadDataConfig: &PreloadDataConfigProperty{
PreloadDataType: jsii.String("preloadDataType"),
},
SseConfiguration: &SseConfigurationProperty{
KmsEncryptionConfig: &KmsEncryptionConfigProperty{
CmkType: jsii.String("cmkType"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
},
},
Tags: []CfnTag{
&CfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
})
func NewCfnFHIRDatastore ¶
func NewCfnFHIRDatastore(scope constructs.Construct, id *string, props *CfnFHIRDatastoreProps) CfnFHIRDatastore
Create a new `AWS::HealthLake::FHIRDatastore`.
type CfnFHIRDatastoreProps ¶
type CfnFHIRDatastoreProps struct {
// The FHIR release version supported by the data store.
//
// Current support is for version `R4` .
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-datastoretypeversion
//
DatastoreTypeVersion *string `field:"required" json:"datastoreTypeVersion" yaml:"datastoreTypeVersion"`
// The data store name (user-generated).
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-datastorename
//
DatastoreName *string `field:"optional" json:"datastoreName" yaml:"datastoreName"`
// The identity provider configuration selected when the data store was created.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-identityproviderconfiguration
//
IdentityProviderConfiguration interface{} `field:"optional" json:"identityProviderConfiguration" yaml:"identityProviderConfiguration"`
// The preloaded Synthea data configuration for the data store.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-preloaddataconfig
//
PreloadDataConfig interface{} `field:"optional" json:"preloadDataConfig" yaml:"preloadDataConfig"`
// The server-side encryption key configuration for a customer-provided encryption key specified for creating a data store.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-sseconfiguration
//
SseConfiguration interface{} `field:"optional" json:"sseConfiguration" yaml:"sseConfiguration"`
// An array of key-value pairs to apply to this resource.
//
// For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-healthlake-fhirdatastore.html#cfn-healthlake-fhirdatastore-tags
//
Tags *[]*awscdk.CfnTag `field:"optional" json:"tags" yaml:"tags"`
}
Properties for defining a `CfnFHIRDatastore`.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnFHIRDatastoreProps := &CfnFHIRDatastoreProps{
DatastoreTypeVersion: jsii.String("datastoreTypeVersion"),
// the properties below are optional
DatastoreName: jsii.String("datastoreName"),
IdentityProviderConfiguration: &IdentityProviderConfigurationProperty{
AuthorizationStrategy: jsii.String("authorizationStrategy"),
// the properties below are optional
FineGrainedAuthorizationEnabled: jsii.Boolean(false),
IdpLambdaArn: jsii.String("idpLambdaArn"),
Metadata: jsii.String("metadata"),
},
PreloadDataConfig: &PreloadDataConfigProperty{
PreloadDataType: jsii.String("preloadDataType"),
},
SseConfiguration: &SseConfigurationProperty{
KmsEncryptionConfig: &KmsEncryptionConfigProperty{
CmkType: jsii.String("cmkType"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
},
},
Tags: []CfnTag{
&CfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
}
type CfnFHIRDatastore_CreatedAtProperty ¶ added in v2.55.0
type CfnFHIRDatastore_CreatedAtProperty struct {
// Nanoseconds.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-createdat.html#cfn-healthlake-fhirdatastore-createdat-nanos
//
Nanos *float64 `field:"required" json:"nanos" yaml:"nanos"`
// Seconds since epoch.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-createdat.html#cfn-healthlake-fhirdatastore-createdat-seconds
//
Seconds *string `field:"required" json:"seconds" yaml:"seconds"`
}
The time that a Data Store was created.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
createdAtProperty := &CreatedAtProperty{
Nanos: jsii.Number(123),
Seconds: jsii.String("seconds"),
}
type CfnFHIRDatastore_IdentityProviderConfigurationProperty ¶ added in v2.88.0
type CfnFHIRDatastore_IdentityProviderConfigurationProperty struct {
// The authorization strategy selected when the HealthLake data store is created.
//
// > HealthLake provides support for both SMART on FHIR V1 and V2 as described below.
// >
// > - `SMART_ON_FHIR_V1` – Support for only SMART on FHIR V1, which includes `read` (read/search) and `write` (create/update/delete) permissions.
// > - `SMART_ON_FHIR` – Support for both SMART on FHIR V1 and V2, which includes `create` , `read` , `update` , `delete` , and `search` permissions.
// > - `AWS_AUTH` – The default HealthLake authorization strategy; not affiliated with SMART on FHIR.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-identityproviderconfiguration.html#cfn-healthlake-fhirdatastore-identityproviderconfiguration-authorizationstrategy
//
AuthorizationStrategy *string `field:"required" json:"authorizationStrategy" yaml:"authorizationStrategy"`
// The parameter to enable SMART on FHIR fine-grained authorization for the data store.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-identityproviderconfiguration.html#cfn-healthlake-fhirdatastore-identityproviderconfiguration-finegrainedauthorizationenabled
//
FineGrainedAuthorizationEnabled interface{} `field:"optional" json:"fineGrainedAuthorizationEnabled" yaml:"fineGrainedAuthorizationEnabled"`
// The Amazon Resource Name (ARN) of the Lambda function to use to decode the access token created by the authorization server.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-identityproviderconfiguration.html#cfn-healthlake-fhirdatastore-identityproviderconfiguration-idplambdaarn
//
IdpLambdaArn *string `field:"optional" json:"idpLambdaArn" yaml:"idpLambdaArn"`
// The JSON metadata elements to use in your identity provider configuration.
//
// Required elements are listed based on the launch specification of the SMART application. For more information on all possible elements, see [Metadata](https://docs.aws.amazon.com/https://build.fhir.org/ig/HL7/smart-app-launch/conformance.html#metadata) in SMART's App Launch specification.
//
// `authorization_endpoint` : The URL to the OAuth2 authorization endpoint.
//
// `grant_types_supported` : An array of grant types that are supported at the token endpoint. You must provide at least one grant type option. Valid options are `authorization_code` and `client_credentials` .
//
// `token_endpoint` : The URL to the OAuth2 token endpoint.
//
// `capabilities` : An array of strings of the SMART capabilities that the authorization server supports.
//
// `code_challenge_methods_supported` : An array of strings of supported PKCE code challenge methods. You must include the `S256` method in the array of PKCE code challenge methods.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-identityproviderconfiguration.html#cfn-healthlake-fhirdatastore-identityproviderconfiguration-metadata
//
Metadata *string `field:"optional" json:"metadata" yaml:"metadata"`
}
The identity provider configuration selected when the data store was created.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
identityProviderConfigurationProperty := &IdentityProviderConfigurationProperty{
AuthorizationStrategy: jsii.String("authorizationStrategy"),
// the properties below are optional
FineGrainedAuthorizationEnabled: jsii.Boolean(false),
IdpLambdaArn: jsii.String("idpLambdaArn"),
Metadata: jsii.String("metadata"),
}
type CfnFHIRDatastore_KmsEncryptionConfigProperty ¶
type CfnFHIRDatastore_KmsEncryptionConfigProperty struct {
// The type of customer-managed-key(CMK) used for encryption.
//
// The two types of supported CMKs are customer owned CMKs and Amazon owned CMKs. For more information on CMK types, see [KmsEncryptionConfig](https://docs.aws.amazon.com/healthlake/latest/APIReference/API_KmsEncryptionConfig.html#HealthLake-Type-KmsEncryptionConfig-CmkType) .
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-kmsencryptionconfig.html#cfn-healthlake-fhirdatastore-kmsencryptionconfig-cmktype
//
CmkType *string `field:"required" json:"cmkType" yaml:"cmkType"`
// The Key Management Service (KMS) encryption key id/alias used to encrypt the data store contents at rest.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-kmsencryptionconfig.html#cfn-healthlake-fhirdatastore-kmsencryptionconfig-kmskeyid
//
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
}
The customer-managed-key(CMK) used when creating a Data Store.
If a customer owned key is not specified, an Amazon owned key will be used for encryption.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
kmsEncryptionConfigProperty := &KmsEncryptionConfigProperty{
CmkType: jsii.String("cmkType"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
}
type CfnFHIRDatastore_PreloadDataConfigProperty ¶
type CfnFHIRDatastore_PreloadDataConfigProperty struct {
// The type of preloaded data.
//
// Only Synthea preloaded data is supported.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-preloaddataconfig.html#cfn-healthlake-fhirdatastore-preloaddataconfig-preloaddatatype
//
PreloadDataType *string `field:"required" json:"preloadDataType" yaml:"preloadDataType"`
}
An optional parameter to preload (import) open source Synthea FHIR data upon creation of the data store.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
preloadDataConfigProperty := &PreloadDataConfigProperty{
PreloadDataType: jsii.String("preloadDataType"),
}
type CfnFHIRDatastore_SseConfigurationProperty ¶
type CfnFHIRDatastore_SseConfigurationProperty struct {
// The server-side encryption key configuration for a customer provided encryption key.
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-healthlake-fhirdatastore-sseconfiguration.html#cfn-healthlake-fhirdatastore-sseconfiguration-kmsencryptionconfig
//
KmsEncryptionConfig interface{} `field:"required" json:"kmsEncryptionConfig" yaml:"kmsEncryptionConfig"`
}
The server-side encryption key configuration for a customer-provided encryption key.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
sseConfigurationProperty := &SseConfigurationProperty{
KmsEncryptionConfig: &KmsEncryptionConfigProperty{
CmkType: jsii.String("cmkType"),
// the properties below are optional
KmsKeyId: jsii.String("kmsKeyId"),
},
}
Source Files
¶
- CfnDataTransformationProfile.go
- CfnDataTransformationProfileProps.go
- CfnDataTransformationProfile_ExistingVersionedProfileSourceProperty.go
- CfnDataTransformationProfile_ProfileMappingSourceProperty.go
- CfnDataTransformationProfile_SourceProperty.go
- CfnDataTransformationProfile_StarterProfileSourceProperty.go
- CfnDataTransformationProfile__checks.go
- CfnFHIRDatastore.go
- CfnFHIRDatastoreProps.go
- CfnFHIRDatastore_CreatedAtProperty.go
- CfnFHIRDatastore_IdentityProviderConfigurationProperty.go
- CfnFHIRDatastore_KmsEncryptionConfigProperty.go
- CfnFHIRDatastore_PreloadDataConfigProperty.go
- CfnFHIRDatastore_SseConfigurationProperty.go
- CfnFHIRDatastore__checks.go
- main.go