Documentation
¶
Index ¶
- func CfnCRL_CFN_RESOURCE_TYPE_NAME() *string
- func CfnCRL_IsCfnElement(x interface{}) *bool
- func CfnCRL_IsCfnResource(construct constructs.IConstruct) *bool
- func CfnCRL_IsConstruct(x interface{}) *bool
- func CfnProfile_CFN_RESOURCE_TYPE_NAME() *string
- func CfnProfile_IsCfnElement(x interface{}) *bool
- func CfnProfile_IsCfnResource(construct constructs.IConstruct) *bool
- func CfnProfile_IsConstruct(x interface{}) *bool
- func CfnTrustAnchor_CFN_RESOURCE_TYPE_NAME() *string
- func CfnTrustAnchor_IsCfnElement(x interface{}) *bool
- func CfnTrustAnchor_IsCfnResource(construct constructs.IConstruct) *bool
- func CfnTrustAnchor_IsConstruct(x interface{}) *bool
- func NewCfnCRL_Override(c CfnCRL, scope constructs.Construct, id *string, props *CfnCRLProps)
- func NewCfnProfile_Override(c CfnProfile, scope constructs.Construct, id *string, props *CfnProfileProps)
- func NewCfnTrustAnchor_Override(c CfnTrustAnchor, scope constructs.Construct, id *string, ...)
- type CfnCRL
- type CfnCRLProps
- type CfnProfile
- type CfnProfileProps
- type CfnTrustAnchor
- type CfnTrustAnchorProps
- type CfnTrustAnchor_SourceDataProperty
- type CfnTrustAnchor_SourceProperty
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CfnCRL_CFN_RESOURCE_TYPE_NAME ¶
func CfnCRL_CFN_RESOURCE_TYPE_NAME() *string
func CfnCRL_IsCfnElement ¶
func CfnCRL_IsCfnElement(x interface{}) *bool
Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).
Uses duck-typing instead of `instanceof` to allow stack elements from different versions of this library to be included in the same stack.
Returns: The construct as a stack element or undefined if it is not a stack element.
func CfnCRL_IsCfnResource ¶
func CfnCRL_IsCfnResource(construct constructs.IConstruct) *bool
Check whether the given construct is a CfnResource.
func CfnCRL_IsConstruct ¶
func CfnCRL_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CfnProfile_CFN_RESOURCE_TYPE_NAME ¶
func CfnProfile_CFN_RESOURCE_TYPE_NAME() *string
func CfnProfile_IsCfnElement ¶
func CfnProfile_IsCfnElement(x interface{}) *bool
Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).
Uses duck-typing instead of `instanceof` to allow stack elements from different versions of this library to be included in the same stack.
Returns: The construct as a stack element or undefined if it is not a stack element.
func CfnProfile_IsCfnResource ¶
func CfnProfile_IsCfnResource(construct constructs.IConstruct) *bool
Check whether the given construct is a CfnResource.
func CfnProfile_IsConstruct ¶
func CfnProfile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CfnTrustAnchor_CFN_RESOURCE_TYPE_NAME ¶
func CfnTrustAnchor_CFN_RESOURCE_TYPE_NAME() *string
func CfnTrustAnchor_IsCfnElement ¶
func CfnTrustAnchor_IsCfnElement(x interface{}) *bool
Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).
Uses duck-typing instead of `instanceof` to allow stack elements from different versions of this library to be included in the same stack.
Returns: The construct as a stack element or undefined if it is not a stack element.
func CfnTrustAnchor_IsCfnResource ¶
func CfnTrustAnchor_IsCfnResource(construct constructs.IConstruct) *bool
Check whether the given construct is a CfnResource.
func CfnTrustAnchor_IsConstruct ¶
func CfnTrustAnchor_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NewCfnCRL_Override ¶
func NewCfnCRL_Override(c CfnCRL, scope constructs.Construct, id *string, props *CfnCRLProps)
Create a new `AWS::RolesAnywhere::CRL`.
func NewCfnProfile_Override ¶
func NewCfnProfile_Override(c CfnProfile, scope constructs.Construct, id *string, props *CfnProfileProps)
Create a new `AWS::RolesAnywhere::Profile`.
func NewCfnTrustAnchor_Override ¶
func NewCfnTrustAnchor_Override(c CfnTrustAnchor, scope constructs.Construct, id *string, props *CfnTrustAnchorProps)
Create a new `AWS::RolesAnywhere::TrustAnchor`.
Types ¶
type CfnCRL ¶
type CfnCRL interface {
awscdk.CfnResource
awscdk.IInspectable
// The unique primary identifier of the Crl.
AttrCrlId() *string
// Options for this resource, such as condition, update policy etc.
CfnOptions() awscdk.ICfnResourceOptions
CfnProperties() *map[string]interface{}
// AWS resource type.
CfnResourceType() *string
// Returns: the stack trace of the point where this Resource was created from, sourced
// from the +metadata+ entry typed +aws:cdk:logicalId+, and with the bottom-most
// node +internal+ entries filtered.
CreationStack() *[]*string
// The x509 v3 specified certificate revocation list (CRL).
CrlData() *string
SetCrlData(val *string)
// Specifies whether the certificate revocation list (CRL) is enabled.
Enabled() interface{}
SetEnabled(val interface{})
// The logical ID for this CloudFormation stack element.
//
// The logical ID of the element
// is calculated from the path of the resource node in the construct tree.
//
// To override this value, use `overrideLogicalId(newLogicalId)`.
//
// Returns: the logical ID as a stringified token. This value will only get
// resolved during synthesis.
LogicalId() *string
// The name of the certificate revocation list (CRL).
Name() *string
SetName(val *string)
// The tree node.
Node() constructs.Node
// Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.
//
// If, by any chance, the intrinsic reference of a resource is not a string, you could
// coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.
Ref() *string
// The stack in which this element is defined.
//
// CfnElements must be defined within a stack scope (directly or indirectly).
Stack() awscdk.Stack
// A list of tags to attach to the certificate revocation list (CRL).
Tags() awscdk.TagManager
// The ARN of the TrustAnchor the certificate revocation list (CRL) will provide revocation for.
TrustAnchorArn() *string
SetTrustAnchorArn(val *string)
// Deprecated.
// Deprecated: use `updatedProperties`
//
// Return properties modified after initiation
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperites() *map[string]interface{}
// Return properties modified after initiation.
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperties() *map[string]interface{}
// Syntactic sugar for `addOverride(path, undefined)`.
AddDeletionOverride(path *string)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
AddDependency(target awscdk.CfnResource)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
// Deprecated: use addDependency.
AddDependsOn(target awscdk.CfnResource)
// Add a value to the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
AddMetadata(key *string, value interface{})
// Adds an override to the synthesized CloudFormation resource.
//
// To add a
// property override, either use `addPropertyOverride` or prefix `path` with
// "Properties." (i.e. `Properties.TopicName`).
//
// If the override is nested, separate each nested level using a dot (.) in the path parameter.
// If there is an array as part of the nesting, specify the index in the path.
//
// To include a literal `.` in the property name, prefix with a `\`. In most
// programming languages you will need to write this as `"\\."` because the
// `\` itself will need to be escaped.
//
// For example,
// “`typescript
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
// “`
// would add the overrides
// “`json
// "Properties": {
// "GlobalSecondaryIndexes": [
// {
// "Projection": {
// "NonKeyAttributes": [ "myattribute" ]
// ...
// }
// ...
// },
// {
// "ProjectionType": "INCLUDE"
// ...
// },
// ]
// ...
// }
// “`
//
// The `value` argument to `addOverride` will not be processed or translated
// in any way. Pass raw JSON values in here with the correct capitalization
// for CloudFormation. If you pass CDK classes or structs, they will be
// rendered with lowercased key names, and CloudFormation will reject the
// template.
AddOverride(path *string, value interface{})
// Adds an override that deletes the value of a property from the resource definition.
AddPropertyDeletionOverride(propertyPath *string)
// Adds an override to a resource property.
//
// Syntactic sugar for `addOverride("Properties.<...>", value)`.
AddPropertyOverride(propertyPath *string, value interface{})
// Sets the deletion policy of the resource based on the removal policy specified.
//
// The Removal Policy controls what happens to this resource when it stops
// being managed by CloudFormation, either because you've removed it from the
// CDK application or because you've made a change that requires the resource
// to be replaced.
//
// The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
// account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
// cases, a snapshot can be taken of the resource prior to deletion
// (`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
// can be found in the following link:.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
//
ApplyRemovalPolicy(policy awscdk.RemovalPolicy, options *awscdk.RemovalPolicyOptions)
// Returns a token for an runtime attribute of this resource.
//
// Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
// in case there is no generated attribute.
GetAtt(attributeName *string, typeHint awscdk.ResolutionTypeHint) awscdk.Reference
// Retrieve a value value from the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
GetMetadata(key *string) interface{}
// Examines the CloudFormation resource and discloses attributes.
Inspect(inspector awscdk.TreeInspector)
// Retrieves an array of resources this resource depends on.
//
// This assembles dependencies on resources across stacks (including nested stacks)
// automatically.
ObtainDependencies() *[]interface{}
// Get a shallow copy of dependencies between this resource and other resources in the same stack.
ObtainResourceDependencies() *[]awscdk.CfnResource
// Overrides the auto-generated logical ID with a specific ID.
OverrideLogicalId(newLogicalId *string)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
RemoveDependency(target awscdk.CfnResource)
RenderProperties(props *map[string]interface{}) *map[string]interface{}
// Replaces one dependency with another.
ReplaceDependency(target awscdk.CfnResource, newTarget awscdk.CfnResource)
// Can be overridden by subclasses to determine if this resource will be rendered into the cloudformation template.
//
// Returns: `true` if the resource should be included or `false` is the resource
// should be omitted.
ShouldSynthesize() *bool
// Returns a string representation of this construct.
//
// Returns: a string representation of this resource.
ToString() *string
ValidateProperties(_properties interface{})
}
A CloudFormation `AWS::RolesAnywhere::CRL`.
Imports the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate Authority (CA). IAM Roles Anywhere validates against the CRL before issuing credentials.
*Required permissions:* `rolesanywhere:ImportCrl` .
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnCRL := awscdk.Aws_rolesanywhere.NewCfnCRL(this, jsii.String("MyCfnCRL"), &CfnCRLProps{
CrlData: jsii.String("crlData"),
Name: jsii.String("name"),
// the properties below are optional
Enabled: jsii.Boolean(false),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
TrustAnchorArn: jsii.String("trustAnchorArn"),
})
func NewCfnCRL ¶
func NewCfnCRL(scope constructs.Construct, id *string, props *CfnCRLProps) CfnCRL
Create a new `AWS::RolesAnywhere::CRL`.
type CfnCRLProps ¶
type CfnCRLProps struct {
// The x509 v3 specified certificate revocation list (CRL).
CrlData *string `field:"required" json:"crlData" yaml:"crlData"`
// The name of the certificate revocation list (CRL).
Name *string `field:"required" json:"name" yaml:"name"`
// Specifies whether the certificate revocation list (CRL) is enabled.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// A list of tags to attach to the certificate revocation list (CRL).
Tags *[]*awscdk.CfnTag `field:"optional" json:"tags" yaml:"tags"`
// The ARN of the TrustAnchor the certificate revocation list (CRL) will provide revocation for.
TrustAnchorArn *string `field:"optional" json:"trustAnchorArn" yaml:"trustAnchorArn"`
}
Properties for defining a `CfnCRL`.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnCRLProps := &CfnCRLProps{
CrlData: jsii.String("crlData"),
Name: jsii.String("name"),
// the properties below are optional
Enabled: jsii.Boolean(false),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
TrustAnchorArn: jsii.String("trustAnchorArn"),
}
type CfnProfile ¶
type CfnProfile interface {
awscdk.CfnResource
awscdk.IInspectable
// The ARN of the profile.
AttrProfileArn() *string
// The unique primary identifier of the Profile.
AttrProfileId() *string
// Options for this resource, such as condition, update policy etc.
CfnOptions() awscdk.ICfnResourceOptions
CfnProperties() *map[string]interface{}
// AWS resource type.
CfnResourceType() *string
// Returns: the stack trace of the point where this Resource was created from, sourced
// from the +metadata+ entry typed +aws:cdk:logicalId+, and with the bottom-most
// node +internal+ entries filtered.
CreationStack() *[]*string
// Sets the maximum number of seconds that vended temporary credentials through [CreateSession](https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication-create-session.html) will be valid for, between 900 and 3600.
DurationSeconds() *float64
SetDurationSeconds(val *float64)
// Indicates whether the profile is enabled.
Enabled() interface{}
SetEnabled(val interface{})
// The logical ID for this CloudFormation stack element.
//
// The logical ID of the element
// is calculated from the path of the resource node in the construct tree.
//
// To override this value, use `overrideLogicalId(newLogicalId)`.
//
// Returns: the logical ID as a stringified token. This value will only get
// resolved during synthesis.
LogicalId() *string
// A list of managed policy ARNs that apply to the vended session credentials.
ManagedPolicyArns() *[]*string
SetManagedPolicyArns(val *[]*string)
// The name of the profile.
Name() *string
SetName(val *string)
// The tree node.
Node() constructs.Node
// Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.
//
// If, by any chance, the intrinsic reference of a resource is not a string, you could
// coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.
Ref() *string
// Specifies whether instance properties are required in temporary credential requests with this profile.
RequireInstanceProperties() interface{}
SetRequireInstanceProperties(val interface{})
// A list of IAM role ARNs.
//
// During `CreateSession` , if a matching role ARN is provided, the properties in this profile will be applied to the intersection session policy.
RoleArns() *[]*string
SetRoleArns(val *[]*string)
// A session policy that applies to the trust boundary of the vended session credentials.
SessionPolicy() *string
SetSessionPolicy(val *string)
// The stack in which this element is defined.
//
// CfnElements must be defined within a stack scope (directly or indirectly).
Stack() awscdk.Stack
// The tags to attach to the profile.
Tags() awscdk.TagManager
// Deprecated.
// Deprecated: use `updatedProperties`
//
// Return properties modified after initiation
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperites() *map[string]interface{}
// Return properties modified after initiation.
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperties() *map[string]interface{}
// Syntactic sugar for `addOverride(path, undefined)`.
AddDeletionOverride(path *string)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
AddDependency(target awscdk.CfnResource)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
// Deprecated: use addDependency.
AddDependsOn(target awscdk.CfnResource)
// Add a value to the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
AddMetadata(key *string, value interface{})
// Adds an override to the synthesized CloudFormation resource.
//
// To add a
// property override, either use `addPropertyOverride` or prefix `path` with
// "Properties." (i.e. `Properties.TopicName`).
//
// If the override is nested, separate each nested level using a dot (.) in the path parameter.
// If there is an array as part of the nesting, specify the index in the path.
//
// To include a literal `.` in the property name, prefix with a `\`. In most
// programming languages you will need to write this as `"\\."` because the
// `\` itself will need to be escaped.
//
// For example,
// “`typescript
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
// “`
// would add the overrides
// “`json
// "Properties": {
// "GlobalSecondaryIndexes": [
// {
// "Projection": {
// "NonKeyAttributes": [ "myattribute" ]
// ...
// }
// ...
// },
// {
// "ProjectionType": "INCLUDE"
// ...
// },
// ]
// ...
// }
// “`
//
// The `value` argument to `addOverride` will not be processed or translated
// in any way. Pass raw JSON values in here with the correct capitalization
// for CloudFormation. If you pass CDK classes or structs, they will be
// rendered with lowercased key names, and CloudFormation will reject the
// template.
AddOverride(path *string, value interface{})
// Adds an override that deletes the value of a property from the resource definition.
AddPropertyDeletionOverride(propertyPath *string)
// Adds an override to a resource property.
//
// Syntactic sugar for `addOverride("Properties.<...>", value)`.
AddPropertyOverride(propertyPath *string, value interface{})
// Sets the deletion policy of the resource based on the removal policy specified.
//
// The Removal Policy controls what happens to this resource when it stops
// being managed by CloudFormation, either because you've removed it from the
// CDK application or because you've made a change that requires the resource
// to be replaced.
//
// The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
// account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
// cases, a snapshot can be taken of the resource prior to deletion
// (`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
// can be found in the following link:.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
//
ApplyRemovalPolicy(policy awscdk.RemovalPolicy, options *awscdk.RemovalPolicyOptions)
// Returns a token for an runtime attribute of this resource.
//
// Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
// in case there is no generated attribute.
GetAtt(attributeName *string, typeHint awscdk.ResolutionTypeHint) awscdk.Reference
// Retrieve a value value from the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
GetMetadata(key *string) interface{}
// Examines the CloudFormation resource and discloses attributes.
Inspect(inspector awscdk.TreeInspector)
// Retrieves an array of resources this resource depends on.
//
// This assembles dependencies on resources across stacks (including nested stacks)
// automatically.
ObtainDependencies() *[]interface{}
// Get a shallow copy of dependencies between this resource and other resources in the same stack.
ObtainResourceDependencies() *[]awscdk.CfnResource
// Overrides the auto-generated logical ID with a specific ID.
OverrideLogicalId(newLogicalId *string)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
RemoveDependency(target awscdk.CfnResource)
RenderProperties(props *map[string]interface{}) *map[string]interface{}
// Replaces one dependency with another.
ReplaceDependency(target awscdk.CfnResource, newTarget awscdk.CfnResource)
// Can be overridden by subclasses to determine if this resource will be rendered into the cloudformation template.
//
// Returns: `true` if the resource should be included or `false` is the resource
// should be omitted.
ShouldSynthesize() *bool
// Returns a string representation of this construct.
//
// Returns: a string representation of this resource.
ToString() *string
ValidateProperties(_properties interface{})
}
A CloudFormation `AWS::RolesAnywhere::Profile`.
Creates a *profile* , a list of the roles that Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.
*Required permissions:* `rolesanywhere:CreateProfile` .
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnProfile := awscdk.Aws_rolesanywhere.NewCfnProfile(this, jsii.String("MyCfnProfile"), &CfnProfileProps{
Name: jsii.String("name"),
RoleArns: []*string{
jsii.String("roleArns"),
},
// the properties below are optional
DurationSeconds: jsii.Number(123),
Enabled: jsii.Boolean(false),
ManagedPolicyArns: []*string{
jsii.String("managedPolicyArns"),
},
RequireInstanceProperties: jsii.Boolean(false),
SessionPolicy: jsii.String("sessionPolicy"),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
})
func NewCfnProfile ¶
func NewCfnProfile(scope constructs.Construct, id *string, props *CfnProfileProps) CfnProfile
Create a new `AWS::RolesAnywhere::Profile`.
type CfnProfileProps ¶
type CfnProfileProps struct {
// The name of the profile.
Name *string `field:"required" json:"name" yaml:"name"`
// A list of IAM role ARNs.
//
// During `CreateSession` , if a matching role ARN is provided, the properties in this profile will be applied to the intersection session policy.
RoleArns *[]*string `field:"required" json:"roleArns" yaml:"roleArns"`
// Sets the maximum number of seconds that vended temporary credentials through [CreateSession](https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication-create-session.html) will be valid for, between 900 and 3600.
DurationSeconds *float64 `field:"optional" json:"durationSeconds" yaml:"durationSeconds"`
// Indicates whether the profile is enabled.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// A list of managed policy ARNs that apply to the vended session credentials.
ManagedPolicyArns *[]*string `field:"optional" json:"managedPolicyArns" yaml:"managedPolicyArns"`
// Specifies whether instance properties are required in temporary credential requests with this profile.
RequireInstanceProperties interface{} `field:"optional" json:"requireInstanceProperties" yaml:"requireInstanceProperties"`
// A session policy that applies to the trust boundary of the vended session credentials.
SessionPolicy *string `field:"optional" json:"sessionPolicy" yaml:"sessionPolicy"`
// The tags to attach to the profile.
Tags *[]*awscdk.CfnTag `field:"optional" json:"tags" yaml:"tags"`
}
Properties for defining a `CfnProfile`.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnProfileProps := &CfnProfileProps{
Name: jsii.String("name"),
RoleArns: []*string{
jsii.String("roleArns"),
},
// the properties below are optional
DurationSeconds: jsii.Number(123),
Enabled: jsii.Boolean(false),
ManagedPolicyArns: []*string{
jsii.String("managedPolicyArns"),
},
RequireInstanceProperties: jsii.Boolean(false),
SessionPolicy: jsii.String("sessionPolicy"),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
}
type CfnTrustAnchor ¶
type CfnTrustAnchor interface {
awscdk.CfnResource
awscdk.IInspectable
// The ARN of the trust anchor.
AttrTrustAnchorArn() *string
// The unique identifier of the trust anchor.
AttrTrustAnchorId() *string
// Options for this resource, such as condition, update policy etc.
CfnOptions() awscdk.ICfnResourceOptions
CfnProperties() *map[string]interface{}
// AWS resource type.
CfnResourceType() *string
// Returns: the stack trace of the point where this Resource was created from, sourced
// from the +metadata+ entry typed +aws:cdk:logicalId+, and with the bottom-most
// node +internal+ entries filtered.
CreationStack() *[]*string
// Indicates whether the trust anchor is enabled.
Enabled() interface{}
SetEnabled(val interface{})
// The logical ID for this CloudFormation stack element.
//
// The logical ID of the element
// is calculated from the path of the resource node in the construct tree.
//
// To override this value, use `overrideLogicalId(newLogicalId)`.
//
// Returns: the logical ID as a stringified token. This value will only get
// resolved during synthesis.
LogicalId() *string
// The name of the trust anchor.
Name() *string
SetName(val *string)
// The tree node.
Node() constructs.Node
// Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.
//
// If, by any chance, the intrinsic reference of a resource is not a string, you could
// coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.
Ref() *string
// The trust anchor type and its related certificate data.
Source() interface{}
SetSource(val interface{})
// The stack in which this element is defined.
//
// CfnElements must be defined within a stack scope (directly or indirectly).
Stack() awscdk.Stack
// The tags to attach to the trust anchor.
Tags() awscdk.TagManager
// Deprecated.
// Deprecated: use `updatedProperties`
//
// Return properties modified after initiation
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperites() *map[string]interface{}
// Return properties modified after initiation.
//
// Resources that expose mutable properties should override this function to
// collect and return the properties object for this resource.
UpdatedProperties() *map[string]interface{}
// Syntactic sugar for `addOverride(path, undefined)`.
AddDeletionOverride(path *string)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
//
// This can be used for resources across stacks (or nested stack) boundaries
// and the dependency will automatically be transferred to the relevant scope.
AddDependency(target awscdk.CfnResource)
// Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.
// Deprecated: use addDependency.
AddDependsOn(target awscdk.CfnResource)
// Add a value to the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
AddMetadata(key *string, value interface{})
// Adds an override to the synthesized CloudFormation resource.
//
// To add a
// property override, either use `addPropertyOverride` or prefix `path` with
// "Properties." (i.e. `Properties.TopicName`).
//
// If the override is nested, separate each nested level using a dot (.) in the path parameter.
// If there is an array as part of the nesting, specify the index in the path.
//
// To include a literal `.` in the property name, prefix with a `\`. In most
// programming languages you will need to write this as `"\\."` because the
// `\` itself will need to be escaped.
//
// For example,
// “`typescript
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
// cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
// “`
// would add the overrides
// “`json
// "Properties": {
// "GlobalSecondaryIndexes": [
// {
// "Projection": {
// "NonKeyAttributes": [ "myattribute" ]
// ...
// }
// ...
// },
// {
// "ProjectionType": "INCLUDE"
// ...
// },
// ]
// ...
// }
// “`
//
// The `value` argument to `addOverride` will not be processed or translated
// in any way. Pass raw JSON values in here with the correct capitalization
// for CloudFormation. If you pass CDK classes or structs, they will be
// rendered with lowercased key names, and CloudFormation will reject the
// template.
AddOverride(path *string, value interface{})
// Adds an override that deletes the value of a property from the resource definition.
AddPropertyDeletionOverride(propertyPath *string)
// Adds an override to a resource property.
//
// Syntactic sugar for `addOverride("Properties.<...>", value)`.
AddPropertyOverride(propertyPath *string, value interface{})
// Sets the deletion policy of the resource based on the removal policy specified.
//
// The Removal Policy controls what happens to this resource when it stops
// being managed by CloudFormation, either because you've removed it from the
// CDK application or because you've made a change that requires the resource
// to be replaced.
//
// The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
// account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
// cases, a snapshot can be taken of the resource prior to deletion
// (`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
// can be found in the following link:.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
//
ApplyRemovalPolicy(policy awscdk.RemovalPolicy, options *awscdk.RemovalPolicyOptions)
// Returns a token for an runtime attribute of this resource.
//
// Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
// in case there is no generated attribute.
GetAtt(attributeName *string, typeHint awscdk.ResolutionTypeHint) awscdk.Reference
// Retrieve a value value from the CloudFormation Resource Metadata.
// See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html
//
// Note that this is a different set of metadata from CDK node metadata; this
// metadata ends up in the stack template under the resource, whereas CDK
// node metadata ends up in the Cloud Assembly.
//
GetMetadata(key *string) interface{}
// Examines the CloudFormation resource and discloses attributes.
Inspect(inspector awscdk.TreeInspector)
// Retrieves an array of resources this resource depends on.
//
// This assembles dependencies on resources across stacks (including nested stacks)
// automatically.
ObtainDependencies() *[]interface{}
// Get a shallow copy of dependencies between this resource and other resources in the same stack.
ObtainResourceDependencies() *[]awscdk.CfnResource
// Overrides the auto-generated logical ID with a specific ID.
OverrideLogicalId(newLogicalId *string)
// Indicates that this resource no longer depends on another resource.
//
// This can be used for resources across stacks (including nested stacks)
// and the dependency will automatically be removed from the relevant scope.
RemoveDependency(target awscdk.CfnResource)
RenderProperties(props *map[string]interface{}) *map[string]interface{}
// Replaces one dependency with another.
ReplaceDependency(target awscdk.CfnResource, newTarget awscdk.CfnResource)
// Can be overridden by subclasses to determine if this resource will be rendered into the cloudformation template.
//
// Returns: `true` if the resource should be included or `false` is the resource
// should be omitted.
ShouldSynthesize() *bool
// Returns a string representation of this construct.
//
// Returns: a string representation of this resource.
ToString() *string
ValidateProperties(_properties interface{})
}
A CloudFormation `AWS::RolesAnywhere::TrustAnchor`.
Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA). You can define a trust anchor as a reference to an AWS Private Certificate Authority ( AWS Private CA ) or by uploading a CA certificate. Your AWS workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary AWS credentials.
*Required permissions:* `rolesanywhere:CreateTrustAnchor` .
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnTrustAnchor := awscdk.Aws_rolesanywhere.NewCfnTrustAnchor(this, jsii.String("MyCfnTrustAnchor"), &CfnTrustAnchorProps{
Name: jsii.String("name"),
Source: &SourceProperty{
SourceData: &SourceDataProperty{
AcmPcaArn: jsii.String("acmPcaArn"),
X509CertificateData: jsii.String("x509CertificateData"),
},
SourceType: jsii.String("sourceType"),
},
// the properties below are optional
Enabled: jsii.Boolean(false),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
})
func NewCfnTrustAnchor ¶
func NewCfnTrustAnchor(scope constructs.Construct, id *string, props *CfnTrustAnchorProps) CfnTrustAnchor
Create a new `AWS::RolesAnywhere::TrustAnchor`.
type CfnTrustAnchorProps ¶
type CfnTrustAnchorProps struct {
// The name of the trust anchor.
Name *string `field:"required" json:"name" yaml:"name"`
// The trust anchor type and its related certificate data.
Source interface{} `field:"required" json:"source" yaml:"source"`
// Indicates whether the trust anchor is enabled.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// The tags to attach to the trust anchor.
Tags *[]*awscdk.CfnTag `field:"optional" json:"tags" yaml:"tags"`
}
Properties for defining a `CfnTrustAnchor`.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
cfnTrustAnchorProps := &CfnTrustAnchorProps{
Name: jsii.String("name"),
Source: &SourceProperty{
SourceData: &SourceDataProperty{
AcmPcaArn: jsii.String("acmPcaArn"),
X509CertificateData: jsii.String("x509CertificateData"),
},
SourceType: jsii.String("sourceType"),
},
// the properties below are optional
Enabled: jsii.Boolean(false),
Tags: []cfnTag{
&cfnTag{
Key: jsii.String("key"),
Value: jsii.String("value"),
},
},
}
type CfnTrustAnchor_SourceDataProperty ¶
type CfnTrustAnchor_SourceDataProperty struct {
// The root certificate of the AWS Private Certificate Authority specified by this ARN is used in trust validation for temporary credential requests.
//
// Included for trust anchors of type `AWS_ACM_PCA` .
//
// > This field is not supported in your region.
AcmPcaArn *string `field:"optional" json:"acmPcaArn" yaml:"acmPcaArn"`
// The PEM-encoded data for the certificate anchor.
//
// Included for trust anchors of type `CERTIFICATE_BUNDLE` .
X509CertificateData *string `field:"optional" json:"x509CertificateData" yaml:"x509CertificateData"`
}
The data field of the trust anchor depending on its type.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
sourceDataProperty := &SourceDataProperty{
AcmPcaArn: jsii.String("acmPcaArn"),
X509CertificateData: jsii.String("x509CertificateData"),
}
type CfnTrustAnchor_SourceProperty ¶
type CfnTrustAnchor_SourceProperty struct {
// The data field of the trust anchor depending on its type.
SourceData interface{} `field:"optional" json:"sourceData" yaml:"sourceData"`
// The type of the TrustAnchor.
//
// > `AWS_ACM_PCA` is not an allowed value in your region.
SourceType *string `field:"optional" json:"sourceType" yaml:"sourceType"`
}
The trust anchor type and its related certificate data.
Example:
// The code below shows an example of how to instantiate this type.
// The values are placeholders you should change.
import "github.com/aws/aws-cdk-go/awscdk"
sourceProperty := &SourceProperty{
SourceData: &SourceDataProperty{
AcmPcaArn: jsii.String("acmPcaArn"),
X509CertificateData: jsii.String("x509CertificateData"),
},
SourceType: jsii.String("sourceType"),
}